TelemetryEvent

Struct TelemetryEvent 

pub struct TelemetryEvent {
Show 13 fields pub header: TelemetryPacketHeader, pub creation_time: u64, pub event_id: u32, pub tracker_hits: Vec<TrackerHit>, pub tracker_oscillators: Vec<u64>, pub tof_event: TofEvent, pub raw_data: Vec<u8>, pub flags0: u8, pub flags1: u8, pub version: u8, pub osc_flags: u8, pub oscillator_idx: Vec<u8>, pub expected_tr_hits: u8,
}
The basic event type as sent over telemetry, often also dubbed as “merged event”.

This event type contains tof as well as tracker hits, and comes in several flavors, depending on the suspected signalness of the online system determined by a specific algorith. For that, please see the TelemetryPacketHeader, which identifiers these different flavors.

For most purposes, this event is the to-go data to start any analysis.

Fields

header: TelemetryPacketHeadercreation_time: u64event_id: u32tracker_hits: Vec<TrackerHit>tracker_oscillators: Vec<u64>tof_event: TofEventraw_data: Vec<u8>flags0: u8flags1: u8version: u8osc_flags: u8oscillator_idx: Vec<u8>expected_tr_hits: u8

Implementations

Source

impl TelemetryEvent

pub fn new() -> Self

pub fn pack(&self) -> TelemetryPacket

Create a TelemetryPacket from the TelemetryEvent.

CAVEAT: Currently the checksum does not get re-evaluated

pub fn calibrate_trk_hits( &mut self, cali: &TrackerOfflineCalibration, ) -> Result<(), CalibrationError>

pub fn hydrate( &mut self, tof_paddles: &HashMap<u8, TofPaddle>, trk_strips: &HashMap<u32, TrackerStrip>, )

Restore position information from database

pub fn delete_all_tracker_hits(&mut self)

Delete tracker hits (e.g. in case they are supposed to be replaced by packet type 80 tracker hits)

pub fn add_tracker_hits(&mut self, hits: &Vec<TrackerHit>)

Add tracker hits (e.g. hits from packet type 80)

pub fn mask_strips(&mut self, masks: &HashMap<u32, TrackerStripMask>)